# Contributing

If you're reading this section, you're probably interested in contributing to
Elixir. Welcome and thanks for your interest in contributing!

Please take a look at the Contributor documentation, familiarize yourself with
using the Elixir Server, and introduce yourself on the mailing list and
share what area of the project you are interested in working on.
